@@ -87,7 +87,6 @@ async def on_ready():
 @client.event
 async def on_message(message):
 
-    user = None
 
     dir_path = None
 
@@ -246,9 +245,7 @@ async def on_message(message):
                     await message.delete()
 
             if command_dict[c]["connect_to_voicechannel"] != False:
-                if user != message.channel.author:
-                    await message.channel.send(f"Only {user.name} can use this command. Please wait until the current song is finished then try again.")
-                    return
+                
                 try:
                     if len(message.content.split(" ")) >= 2:
                         if "https://" in message.content.split(" ")[1]:
@@ -257,14 +254,14 @@ async def on_message(message):
                             song_name = random.randint(1, 1000)
                             if platform.system() == "Windows":
                                 command_dict[c]["source_to_play"] = f"{dir_path}\{song_name}.mp3"
-                                if "Usage" not in subprocess.getoutput("youtube-dl"):
-                                    if "Usage" not in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
+                                if "Usage" in subprocess.getoutput("youtube-dl"):
+                                    if "Usage" in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
                                         print("Please install YouTube-dl to play music.")
                                         return
                                 subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
                             if platform.system() != "Windows":
                                 command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
-                                if "Usage" not in subprocess.getoutput("youtube-dl"):
+                                if "Usage" in subprocess.getoutput("youtube-dl"):
                                     print("Please install Youtube-dl to continue")
                                     return
                                 subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
@@ -276,7 +273,7 @@ async def on_message(message):
                             print(
                                 "Bot will not play audio because no source file was given.")
                             return
-                        
+
 
                     file_to_play = FFmpegPCMAudio(
                         command_dict[c]["source_to_play"])
@@ -307,9 +304,6 @@ async def on_message(message):
                 except Exception as DM_error:
                     print(str(DM_error))
             if command_dict[c]["disconnect_from_voice_channel"] != False:
-                if user != message.author:
-                    await message.channel.send(f"Only {user.name} can use this command. Please wait until this song is finished, then try again.")
-                return
                 try:
                     await message.guild.voice_client.disconnect()
                 except Exception as disconnect_error:
